@@ -8,11 +8,12 @@ use warnings;
 use base 'Mojo::Base';
 use overload '""' => sub { shift->to_string }, fallback => 1;
 
-use Carp;
+use Carp 'croak';
+use Mojo::ByteStream 'b';
 use Mojo::Date;
 
 __PACKAGE__->attr(
-    [qw/comment domain httponly name path secure value version/]);
+    [qw/comment domain httponly name path port secure value version/]);
 
 # My Homer is not a communist.
 # He may be a liar, a pig, an idiot, a communist, but he is not a porn star.
@@ -61,7 +62,7 @@ sub _tokenize {
             //x
               )
             {
-                $value = Mojo::ByteStream->new($1)->unquote;
+                $value = b($1)->unquote;
             }
 
             # "expires" is a special case, thank you Netscape...
@@ -114,6 +115,8 @@ L<Mojo::Cookie> is a cookie base class.
 
 =head1 ATTRIBUTES
 
+L<Mojo::Cookie> implements the following attributes.
+
 =head2 C<comment>
 
     my $comment = $cookie->comment;
@@ -149,6 +152,11 @@ L<Mojo::Cookie> is a cookie base class.
     my $path = $cookie->path;
     $cookie  = $cookie->path('/test');
 
+=head2 C<port>
+
+    my $port = $cookie->port;
+    $cookie  = $cookie->port('80 8080');
+
 =head2 C<secure>
 
     my $secure = $cookie->secure;
