@@ -54,6 +54,11 @@ sub startup {
         method    => 'test'
     );
 
+    # /staged - authentication with bridges
+    my $b =
+      $r->bridge('/staged')->to(controller => 'foo', action => 'stage1');
+    $b->route->to(controller => 'foo', action => 'stage2');
+
     # /*/* - the default route
     $r->route('/(controller)/(action)')->to(action => 'index');
 }
